.file-link[data-v-795359ad]{color:var(--ac-brand-primary);text-decoration:underline;cursor:pointer}.file-link[data-v-795359ad]:hover{opacity:.8}.log-highlight[data-v-795359ad]{background-color:var(--ac-color-warning);color:inherit;border-radius:2px;padding:0 1px}.logs-pagination[data-v-41b20d5e]{display:flex;align-items:center;gap:2px}.pg-arrow[data-v-41b20d5e],.pg-item[data-v-41b20d5e],.pg-jump[data-v-41b20d5e]{min-width:34px;height:34px;padding:0 8px;display:inline-flex;align-items:center;justify-content:center;border:1px solid transparent;border-radius:6px;background:transparent;color:var(--ac-text-primary);font-size:16px;line-height:1;cursor:pointer}.pg-arrow[data-v-41b20d5e]:hover:not(:disabled),.pg-item[data-v-41b20d5e]:hover:not(:disabled),.pg-jump[data-v-41b20d5e]:hover:not(:disabled){color:var(--ac-brand-primary)}.pg-arrow[data-v-41b20d5e]:disabled,.pg-item[data-v-41b20d5e]:disabled,.pg-jump[data-v-41b20d5e]:disabled{opacity:.4;cursor:not-allowed}.pg-item.active[data-v-41b20d5e]{border-color:var(--ac-brand-primary);color:var(--ac-brand-primary)}.pg-jump .chevron[data-v-41b20d5e]{display:none}.pg-jump:hover:not(:disabled) .dots[data-v-41b20d5e]{display:none}.pg-jump:hover:not(:disabled) .chevron[data-v-41b20d5e]{display:inline;color:var(--ac-brand-primary)}.cli[data-v-9c4c6a77]{background-color:var(--ac-terminal-bg);border-radius:5px;padding:10px;color:var(--ac-terminal-text);font-family:monospace;overflow-x:hidden;word-break:break-all;white-space:pre-wrap;max-width:100%}.cli .copy-button[data-v-9c4c6a77]{position:absolute;top:4px;right:4px;z-index:10;color:var(--ac-text-tertiary);display:flex;align-items:center;justify-content:center;padding:4px}.cli .copy-button[data-v-9c4c6a77]:hover{color:var(--ac-terminal-text)}.copy-btn[data-v-902b145e]{color:var(--ac-text-tertiary);display:flex;align-items:center;justify-content:center;padding:4px;flex-shrink:0}.copy-btn[data-v-902b145e]:hover{color:var(--ac-text-primary)}.body-content[data-v-e3c5f651]{margin:4px 0 0;padding:8px;background-color:var(--ac-bg-secondary);border-radius:4px;white-space:pre-wrap;word-break:break-all;font-family:monospace;font-size:12px;max-height:200px;overflow:auto}[data-v-e3c5f651] .ant-collapse-header{padding:0!important}[data-v-e3c5f651] .ant-collapse-content-box{padding:4px 0!important}.body-content[data-v-e2be4c22]{margin:4px 0 0;padding:8px;background-color:var(--ac-bg-secondary);border-radius:4px;white-space:pre-wrap;word-break:break-all;font-family:monospace;font-size:12px;max-height:200px;overflow:auto}[data-v-e2be4c22] .ant-collapse-header{padding:0!important}[data-v-e2be4c22] .ant-collapse-content-box{padding:4px 0!important}.fix-with-ai[data-v-45d03aea]{display:flex;gap:4px;align-items:center;cursor:pointer;color:var(--ac-brand-primary);font-size:12px;padding:0 8px}.fix-with-ai[data-v-45d03aea]:hover{opacity:.8}.fix-with-ai.disabled[data-v-45d03aea]{cursor:not-allowed;opacity:.5}
