import{N as c}from"./Navbar-DBn2TIBo.js";import{e as d,V as u,b as a,l,Z as f,f as _,g as b,q as p,k as y,ar as I}from"./jwt-decode.esm-CZajAnkk.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-BpvNJyII.js";import"./LoadingOutlined-C3cOtTgj.js";import"./constants-DBenAw06.js";import"./PhCaretDown.vue-DkkrLaFQ.js";import"./PhPencilSimple.vue-fGWTL7sp.js";import"./router-C8CCuUKN.js";import"./ts.worker-CbdM7mxv.js";import"./organization-CkvaBeNd.js";import"./tables-BosOXgsx.js";import"./string-CFhNxAoY.js";import"./keyboard-BYJ3Kx3e.js";import"./os-BNAUa7pj.js";import"./projectStore-DZ-D9Wa_.js";import"./member-D3C_DPKf.js";import"./project-DTFW8XGL.js";import"./organizationSwitcher-C5dAiDRY.js";import"./cascaderStore-BpKZSTEF.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-zW7Bz1Uu.js";import"./index-DHlnHzhj.js";import"./index-Dl2ekNlA.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-CuFgWt7G.js";import"./PhNotePencil.vue-1u8jRlh-.js";import"./PhTranslate.vue-DiqbZ_s3.js";import"./PhSignOut.vue-BGz8cq8Y.js";import"./index-TXmLIIyx.js";import"./index-1OpTpjsM.js";import"./PhPlus.vue-BC_ucmWH.js";import"./omniChatStore-ecvMt5kJ.js";import"./files-D9_9W1Hf.js";import"./contracts.generated-BALdEKZ5.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";import"./uuid-DSTkeDkZ.js";import"./PhCopySimple.vue-B-FFsTOt.js";import"./PhSparkle.vue-Bpmxa050.js";import"./index-DZmSTval.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8d4aa0ea-6dbe-41ea-8db9-a9edccadfbeb",e._sentryDebugIdIdentifier="sentry-dbid-8d4aa0ea-6dbe-41ea-8db9-a9edccadfbeb")}catch{}})();const g={class:"console-layout"},v={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return b(),_("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",v,[p(r)])])}}}),no=I(w,[["__scopeId","data-v-62f8634d"]]);export{no as default};
//# sourceMappingURL=ConsoleLayout-CWXgNb1M.js.map
