import{aA as r,aB as n,aC as o,aD as p,aE as d,aF as c,aG as f,aH as m,aI as u,aJ as s,aK as g,aL as l,aM as y}from"./jwt-decode.esm-CZajAnkk.js";import{b,s as w,g as h}from"./workspaceStore-B2G7PrH8.js";import{_ as I}from"./App.vue_vue_type_style_index_0_lang-BhTtqnrJ.js";import{r as i}from"./router-DYuV-_RS.js";import"./userStore-BD2sJQ0n.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";import"./PlayerConfigProvider-qAK23XLS.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="312de105-7be9-4e6b-8f25-14c8fa7de120",a._sentryDebugIdIdentifier="sentry-dbid-312de105-7be9-4e6b-8f25-14c8fa7de120")}catch{}})();class _{static init(){setInterval(()=>{b("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const a=await h(),t=r(),e=n({render:()=>o(I)});p.init(),d(e,i,a),_.init(),e.use(i),e.use(t),e.use(c),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",m),e.component("Message",u),s(e,g),s(e,l),s(e,y)})();
//# sourceMappingURL=player-C0MpMrcd.js.map
