import{_ as s}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Pd_jXNCE.js";import{L as i}from"./CircularLoading-D6CW-lVm.js";import{e as c,J as d,$ as l,f as u,g as f,q as n,w as p,k as _,S as h,p as w,l as m,ar as g}from"./jwt-decode.esm-CZajAnkk.js";import{a as b}from"./router-C8CCuUKN.js";import"./logo-BiWG9_W5.js";import"./Logo-DM5mhRuS.js";import"./ts.worker-CbdM7mxv.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7184d181-b7d4-4972-a843-894936020b83",e._sentryDebugIdIdentifier="sentry-dbid-7184d181-b7d4-4972-a843-894936020b83")}catch{}})();const y=e=>{const a=new URLSearchParams(e.replace(/^#/,"")),t=a.get("jwt"),o=a.get("error"),r={};return t&&(r.jwt=t),o&&(r.error=o),r},k={class:"oauth-callback"},I={class:"message"},j=c({__name:"OAuthCallback",setup(e){const a=d();return l(async()=>{const{jwt:t,error:o}=y(window.location.hash);if(window.location.hash&&window.history.replaceState(null,"",window.location.pathname+window.location.search),o||!t){await a.push({name:"login",query:{error:o??"oidc_login_failed"}});return}if(!b.saveJWT(t)){await a.push({name:"login",query:{error:"oidc_login_failed"}});return}await a.push({path:"/"})}),(t,o)=>(f(),u("div",k,[n(s,{"hide-text":"",size:"large"}),n(i,{direction:"column",justify:"center"},{default:p(()=>[_("span",I,h(w(m).translate("i18n_auth_authenticating")),1)]),_:1})]))}}),L=g(j,[["__scopeId","data-v-dcad4324"]]);export{L as default};
//# sourceMappingURL=OAuthCallback-R7H7ny0D.js.map
