import{P as h}from"./PlayerNavbar-Gr6xn4B-.js";import{e as _,V as y,r as b,b as k,f as w,n as p,j as v,k as L,p as t,Z as C,J as I,g as s,ar as P}from"./jwt-decode.esm-CZajAnkk.js";import{u as N}from"./workspaceStore-B2G7PrH8.js";import"./userStore-BD2sJQ0n.js";import"./metadata-CfEi-IxO.js";import"./PhCursorClick.vue-CBE2laQW.js";import"./PhHouse.vue-DkBF1kve.js";import"./PhMagnifyingGlass.vue-CIDyhW5D.js";import"./PhWebhooksLogo.vue-nty9ly2q.js";import"./LoadingOutlined-C3cOtTgj.js";import"./PhSignOut.vue-BGz8cq8Y.js";import"./index-1OpTpjsM.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="c9623112-ce84-4e13-8e8a-a923f608bc72",o._sentryDebugIdIdentifier="sentry-dbid-c9623112-ce84-4e13-8e8a-a923f608bc72")}catch{}})();const V={class:"main-container"},B={class:"content"},D=_({__name:"Main",setup(o){const e=I(),a=y(),n=N(),u=a.path,r=b(null),l=async({path:i,id:c})=>{r.value=c,await e.push({path:`/${i}`}),r.value=null},d=()=>{e.push({name:"playerLogin"})},m=()=>{e.push({name:"playerLogin"})},f=k(()=>!!a.meta.hideLogin);return(i,c)=>{const g=C("RouterView");return s(),w("div",V,[t(n).state.workspace&&t(n).state.currentPageType!=="page"?(s(),p(h,{key:0,"current-path":t(u),"hide-login":f.value,"runner-data":t(n).state.workspace,loading:r.value,"show-sidebar":t(n).state.currentPageType==="form",onNavigate:l,onLoginClick:m,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):v("",!0),L("section",B,[(s(),p(g,{key:t(a).fullPath}))])])}}}),G=P(D,[["__scopeId","data-v-4b9b2f4b"]]);export{G as default};
//# sourceMappingURL=Main-BOnFWz8i.js.map
