.oauth-callback[data-v-dcad4324]{display:flex;flex-direction:column;align-items:center;justify-content:center;gap:32px;height:100vh}.oauth-callback .message[data-v-dcad4324]{font-family:DM Sans,sans-serif;font-size:16px;font-weight:400;color:var(--ac-text-secondary)}
