import{cG as c}from"./jwt-decode.esm-CZajAnkk.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="470ecf83-670d-4ce4-9d63-c81f0151bfa3",r._sentryDebugIdIdentifier="sentry-dbid-470ecf83-670d-4ce4-9d63-c81f0151bfa3")}catch{}})();var m,I;function H(){if(I)return m;I=1;function r(e){var n=typeof e;return e!=null&&(n=="object"||n=="function")}return m=r,m}var y,w;function U(){if(w)return y;w=1;var r=typeof c=="object"&&c&&c.Object===Object&&c;return y=r,y}var g,R;function A(){if(R)return g;R=1;var r=U(),e=typeof self=="object"&&self&&self.Object===Object&&self,n=r||e||Function("return this")();return g=n,g}var v,G;function X(){if(G)return v;G=1;var r=A(),e=function(){return r.Date.now()};return v=e,v}var j,x;function W(){if(x)return j;x=1;var r=/\s/;function e(n){for(var i=n.length;i--&&r.test(n.charAt(i)););return i}return j=e,j}var l,N;function z(){if(N)return l;N=1;var r=W(),e=/^\s+/;function n(i){return i&&i.slice(0,r(i)+1).replace(e,"")}return l=n,l}var T,k;function F(){if(k)return T;k=1;var r=A(),e=r.Symbol;return T=e,T}var _,E;function C(){if(E)return _;E=1;var r=F(),e=Object.prototype,n=e.hasOwnProperty,i=e.toString,o=r?r.toStringTag:void 0;function u(a){var f=n.call(a,o),b=a[o];try{a[o]=void 0;var t=!0}catch{}var s=i.call(a);return t&&(f?a[o]=b:delete a[o]),s}return _=u,_}var S,D;function J(){if(D)return S;D=1;var r=Object.prototype,e=r.toString;function n(i){return e.call(i)}return S=n,S}var q,L;function K(){if(L)return q;L=1;var r=F(),e=C(),n=J(),i="[object Null]",o="[object Undefined]",u=r?r.toStringTag:void 0;function a(f){return f==null?f===void 0?o:i:u&&u in Object(f)?e(f):n(f)}return q=a,q}var O,P;function M(){if(P)return O;P=1;function r(e){return e!=null&&typeof e=="object"}return O=r,O}var p,B;function Q(){if(B)return p;B=1;var r=K(),e=M(),n="[object Symbol]";function i(o){return typeof o=="symbol"||e(o)&&r(o)==n}return p=i,p}var h,$;function Y(){if($)return h;$=1;var r=z(),e=H(),n=Q(),i=NaN,o=/^[-+]0x[0-9a-f]+$/i,u=/^0b[01]+$/i,a=/^0o[0-7]+$/i,f=parseInt;function b(t){if(typeof t=="number")return t;if(n(t))return i;if(e(t)){var s=typeof t.valueOf=="function"?t.valueOf():t;t=e(s)?s+"":s}if(typeof t!="string")return t===0?t:+t;t=r(t);var d=u.test(t);return d||a.test(t)?f(t.slice(2),d?2:8):o.test(t)?i:+t}return h=b,h}export{H as a,A as b,M as c,U as d,F as e,Q as f,Y as g,X as h,K as r};
//# sourceMappingURL=toNumber-DG2G0JpS.js.map
