import{e as l,b as o,f as s,j as r,x as d,S as f,a_ as g,g as t,ar as u}from"./jwt-decode.esm-CZajAnkk.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c504f4a8-f73a-472c-a0cb-29efe7923e62",e._sentryDebugIdIdentifier="sentry-dbid-c504f4a8-f73a-472c-a0cb-29efe7923e62")}catch{}})();const m={class:"logo"},b=["src","alt"],y=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){g(i=>({v4521d904:n.value}));const a=e,n=o(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),c=o(()=>`${a.brandName} Logo`);return(i,p)=>(t(),s("div",m,[e.imageUrl?(t(),s("img",{key:0,class:"logo-img",src:e.imageUrl,alt:c.value},null,8,b)):r("",!0),e.hideText?r("",!0):(t(),s("span",{key:1,class:d(e.size)},f(e.brandName),3))]))}}),_=u(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-DM5mhRuS.js.map
