import{q as l,I as o,F as u}from"./jwt-decode.esm-CZajAnkk.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="530adcb3-a2a3-4f90-affa-80350f19a304",e._sentryDebugIdIdentifier="sentry-dbid-530adcb3-a2a3-4f90-affa-80350f19a304")}catch{}})();function f(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(a){return Object.getOwnPropertyDescriptor(r,a).enumerable}))),n.forEach(function(a){c(e,a,r[a])})}return e}function c(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var i=function(t,r){var n=f({},t,r.attrs);return l(o,f({},n,{icon:u}),null)};i.displayName="CloseCircleOutlined";i.inheritAttrs=!1;export{i as C};
//# sourceMappingURL=CloseCircleOutlined-Qu9aWgjz.js.map
