import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Pd_jXNCE.js";import{A as h}from"./constants-DBenAw06.js";import{e as v,b as w,V as A,l as r,f as B,q as i,n as p,j as f,w as t,p as e,a0 as I,aO as _,B as x,R as a,S as u,k as C,aQ as N,J as S,g as c,ar as T}from"./jwt-decode.esm-CZajAnkk.js";import{u as D}from"./workspaceStore-B2G7PrH8.js";import{C as E}from"./index-Dl2ekNlA.js";import"./logo-BiWG9_W5.js";import"./Logo-DM5mhRuS.js";import"./userStore-BD2sJQ0n.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new j().stack;d&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[d]="bb55016e-f3a0-415e-84e7-55668b1d2785",o._sentryDebugIdIdentifier="sentry-dbid-bb55016e-f3a0-415e-84e7-55668b1d2785")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},H=v({__name:"Error",setup(o){const d=A(),g=S(),m=D(),b=w(()=>m.state.workspace?.name??m.state.workspace?.brandName),n=w(()=>{const{status:l}=d.params;switch(l){case"404":return{status:l,title:r.translate("i18n_page_not_found"),message:r.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:l,title:r.translate("i18n_access_denied"),message:r.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:r.translate("i18n_internal_error"),message:r.translate("i18n_internal_error_message"),showAd:!1}}}),y=()=>{g.push({name:"playerHome"})};return(l,s)=>(c(),B("div",R,[i(e(I),null,{default:t(()=>[a(u(n.value.title),1)]),_:1}),i(e(_),{class:"message"},{default:t(()=>[a(u(n.value.message),1)]),_:1}),n.value.action?(c(),p(e(x),{key:0,type:"link",onClick:y},{default:t(()=>[a(u(n.value.action),1)]),_:1})):f("",!0),n.value.showAd?(c(),p(e(E),{key:1,bordered:!1,class:"card"},{default:t(()=>[C("div",V,[i(k,{style:{"margin-bottom":"10px"}}),i(e(_),null,{default:t(()=>[a("This page is part of "+u(b.value?`the ${b.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(m).state.workspace?(c(),p(e(_),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),i(e(N),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):f("",!0)])]),_:1})):f("",!0)]))}}),j=T(H,[["__scopeId","data-v-522ad0d4"]]);export{j as default};
//# sourceMappingURL=Error-CRUBQ27H.js.map
