import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-CbDeuNmW.js";import{e as i,f as u,q as d,p as n,J as m,V as f,g as l,ar as _}from"./jwt-decode.esm-CZajAnkk.js";import{u as g}from"./workspaceStore-B2G7PrH8.js";import"./OTPInput-3zvejt3v.js";import"./Logo-DM5mhRuS.js";import"./string-CFhNxAoY.js";import"./CircularLoading-D6CW-lVm.js";import"./index-CadB79EP.js";import"./userStore-BD2sJQ0n.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6e21f61c-20d2-43e0-8876-15704f2cebe9",e._sentryDebugIdIdentifier="sentry-dbid-6e21f61c-20d2-43e0-8876-15704f2cebe9")}catch{}})();const y={class:"runner"},b=i({__name:"Login",setup(e){const o=m(),r=f(),t=g(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(l(),u("div",y,[d(p,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(b,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-vlD1Eo9u.js.map
