import{_ as r}from"./logo-BiWG9_W5.js";import{L as o}from"./Logo-DM5mhRuS.js";import{e as s,n as a,p as i,g as f}from"./jwt-decode.esm-CZajAnkk.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5ca56f32-1f47-4999-9fb2-f82c120cd32e",e._sentryDebugIdIdentifier="sentry-dbid-5ca56f32-1f47-4999-9fb2-f82c120cd32e")}catch{}})();const u=s({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(f(),a(o,{"image-url":i(r),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-Pd_jXNCE.js.map
