import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Pd_jXNCE.js";import{B as y}from"./BaseLayout-BsXApDIb.js";import{e as l,K as _,bG as b,ar as u,an as v,ao as g,g as m,f as h,k as a,y as n,$ as w,J as S,n as k,w as s,V as $,q as i,p as B}from"./jwt-decode.esm-CZajAnkk.js";import{u as I}from"./editor-BS5VlMF8.js";import{A as L}from"./index-DZmSTval.js";import"./logo-BiWG9_W5.js";import"./Logo-DM5mhRuS.js";import"./ts.worker-CbdM7mxv.js";import"./workspaceStore-B2G7PrH8.js";import"./userStore-BD2sJQ0n.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";import"./useCodebaseEvents-BMrCPgGM.js";import"./contracts.generated-BALdEKZ5.js";import"./files-D9_9W1Hf.js";import"./PhBug.vue-C7eUT8OS.js";import"./router-DYuV-_RS.js";import"./constants-DBenAw06.js";import"./index-TXmLIIyx.js";import"./index-1OpTpjsM.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="63e3d066-83bc-4762-ae42-979666d6d935",e._sentryDebugIdIdentifier="sentry-dbid-63e3d066-83bc-4762-ae42-979666d6d935")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),D={class:"v-spinner"};function K(e,r,o,d,c,p){return v((m(),h("div",D,[a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(x,[["render",K],["__scopeId","data-v-224007fd"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=$(),o=S(),d=I();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){o.push({name:"error"});return}await d.createLogin(t).then(c),o.push({name:"editor"})}),(t,A)=>(m(),k(y,null,{navbar:s(()=>[i(B(L),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[a("div",R,[i(P)])]),_:1}))}}),re=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-D7V_FvWw.js.map
