import{e as _,J as p,V as f,l as s,n as m,g as c,w as d,f as g,W as y,X as v,q as k,p as n,k as w,S as I}from"./jwt-decode.esm-CZajAnkk.js";import{u as S}from"./projectStore-DZ-D9Wa_.js";import{A as T,T as D}from"./index-Dl2ekNlA.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a6bd0ba5-cb3d-428c-9dc4-6dee3f6384e9",e._sentryDebugIdIdentifier="sentry-dbid-a6bd0ba5-cb3d-428c-9dc4-6dee3f6384e9")}catch{}})();const x=_({__name:"TablesTabs",setup(e){const a=p(),r=f(),i=String(r.name),u=S(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=l=>{a.push({name:String(l),params:{projectId:u.projectId}})};return(l,h)=>(c(),m(n(D),{"active-key":n(i),options:o,"onUpdate:activeKey":b},{default:d(()=>[(c(),g(y,null,v(o,t=>k(n(T),{key:t.value,name:t.value},{tab:d(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{x as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-BdVFnsrV.js.map
