import{A as n}from"./index-DuICX_K0.js";import{e as a,b as r,f as o,j as d,x as c,q as f,p as l,g as p,ar as i}from"./jwt-decode.esm-CZajAnkk.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5edb264c-ad65-43ad-8d3b-4aeb51a68e77",e._sentryDebugIdIdentifier="sentry-dbid-5edb264c-ad65-43ad-8d3b-4aeb51a68e77")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(b,m)=>e.stepsInfo?(p(),o("nav",{key:0,class:c(["p-steps",{"full-screen":!e.isPreview}])},[f(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):d("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-XGJYDVJ8.js.map
