import{O as d}from"./workspaceStore-B2G7PrH8.js";import{e as c,$ as f,f as u,q as n,w as o,p as t,a0 as _,U as p,R as r,S as i,l as s,g}from"./jwt-decode.esm-CZajAnkk.js";import"./userStore-BD2sJQ0n.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="75e76776-3816-40a3-80f0-8c058a7df135",e._sentryDebugIdIdentifier="sentry-dbid-75e76776-3816-40a3-80f0-8c058a7df135")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new d().loginCallback()}),(a,l)=>(g(),u("div",null,[n(t(_),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(t(p),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback--ReXprSS.js.map
