import{b as r}from"./router-C8CCuUKN.js";import"./jwt-decode.esm-CZajAnkk.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="8bf4f6ca-2ee5-493e-a432-33782f40c5dd",n._sentryDebugIdIdentifier="sentry-dbid-8bf4f6ca-2ee5-493e-a432-33782f40c5dd")}catch{}})();function s(n){return n?n.role==="admin"||n.role==="debugger":!1}class d{async create(e){return r.post(`organizations/${e.organizationId}/members`,{email:e.email,folderIds:e.folderIds})}async delete(e){return r.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return r.get(`organizations/${e}/members`)}async get(e,t){return r.get(`organizations/${e}/members/${t}`)}async update(e,t,a){return r.patch(`organizations/${e}/members/${t}`,a)}async updateRole(e,t,a){return r.patch(`organizations/${e}/members/${t}`,{role:a})}async me(e){return r.get(`organizations/${e}/me`)}}export{d as M,s as i};
//# sourceMappingURL=member-D3C_DPKf.js.map
