import{O as l}from"./workspaceStore-B2G7PrH8.js";import{e as c,$ as u,f,q as o,w as n,p as a,a0 as _,U as p,R as r,S as d,l as s,g as b}from"./jwt-decode.esm-CZajAnkk.js";import"./userStore-BD2sJQ0n.js";import"./runnerData-BvOYrde2.js";import"./url-CT13c0nd.js";import"./colorHelpers-C087BzGB.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2b2a45d2-2052-4d67-8d44-16faa926407d",e._sentryDebugIdIdentifier="sentry-dbid-2b2a45d2-2052-4d67-8d44-16faa926407d")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(t,i)=>(b(),f("div",null,[o(a(_),null,{default:n(()=>[r(d(a(s).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(d(a(s).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-CR7FAcjB.js.map
