import{e as d,f as o,g as i,q as n,w as r,p as a,l,k as c,ar as f}from"./jwt-decode.esm-CZajAnkk.js";import{R as _}from"./index-BeNltMA8.js";import{C as u}from"./index-Dl2ekNlA.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="260b142e-0dee-4184-858a-6108768e220a",e._sentryDebugIdIdentifier="sentry-dbid-260b142e-0dee-4184-858a-6108768e220a")}catch{}})();const p={class:"credentials-page"},m=d({__name:"CredentialsSuccessView",setup(e){return(t,s)=>(i(),o("div",p,[n(a(u),{class:"credentials-card"},{default:r(()=>[n(a(_),{title:a(l).translate("i18n_credential_form_thank_you")},{icon:r(()=>[...s[0]||(s[0]=[c("span",null,null,-1)])]),_:1},8,["title"])]),_:1})]))}}),g=f(m,[["__scopeId","data-v-f9bd641e"]]);export{g as default};
//# sourceMappingURL=CredentialsSuccessView-WHrQVOCg.js.map
