import{B as y}from"./BaseLayout-BsXApDIb.js";import{C as v}from"./ContentLayout-Hcty3nNF.js";import{e as h,b as r,l as d,f as g,g as o,k as _,S as p,p as u,W as b,X as B,n as c,B as C,w as f,R as z,V as M,N as S,Z as V,q as $,j as I}from"./jwt-decode.esm-CZajAnkk.js";import{_ as R}from"./BillingAlert.vue_vue_type_script_setup_true_lang-DpgeT0Hj.js";import{E as x}from"./router-C8CCuUKN.js";import{u as D}from"./projectsStore-BjPuofVb.js";import"./index-CadB79EP.js";import"./ts.worker-CbdM7mxv.js";import"./member-D3C_DPKf.js";import"./organization-CkvaBeNd.js";import"./project-DTFW8XGL.js";import"./tables-BosOXgsx.js";import"./string-CFhNxAoY.js";import"./cascaderStore-BpKZSTEF.js";import"./organizationSwitcher-C5dAiDRY.js";import"./ant-design-CiKENTgs.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="2bb66e54-0944-4e15-9630-67bab14d6456",a._sentryDebugIdIdentifier="sentry-dbid-2bb66e54-0944-4e15-9630-67bab14d6456")}catch{}})();const L={class:"org-login-blocked"},N={class:"actions"},j=h({__name:"OrgLoginBlocked",props:{allowedMethods:{}},setup(a){const n=a,i=r(()=>n.allowedMethods.filter(e=>e==="google"||e==="microsoft")),s=r(()=>d.translate("i18n_org_login_blocked_message",null,{methods:n.allowedMethods.join(", ")})),m=e=>{const l=encodeURIComponent(`${window.location.origin}/auth/callback`);window.location.href=`${x.cloudApi}/console/authn/oauth/${e}/start?redirect=${l}`};return(e,l)=>(o(),g("div",L,[_("h2",null,p(u(d).translate("i18n_org_login_blocked_title")),1),_("p",null,p(s.value),1),_("div",N,[(o(!0),g(b,null,B(i.value,t=>(o(),c(u(C),{key:t,type:"primary",onClick:w=>m(t)},{default:f(()=>[z(p(t==="google"?u(d).translate("i18n_auth_continue_with_google"):u(d).translate("i18n_auth_continue_with_microsoft")),1)]),_:2},1032,["onClick"]))),128))])]))}}),Y=h({__name:"Organization",setup(a){const n=M(),i=D(),s=r(()=>n.params.organizationId);S(s,t=>{t&&i.fetchedState?.organization?.id!==t&&i.fetchState(t)},{immediate:!0});const m=r(()=>i.fetchedState?.organization),e=r(()=>m.value?.billingMetadata),l=r(()=>i.loginBlocked);return(t,w)=>{const k=V("RouterView");return o(),c(y,null,{content:f(()=>[$(v,null,{default:f(()=>[l.value?(o(),c(j,{key:0,"allowed-methods":l.value.allowedMethods},null,8,["allowed-methods"])):(o(),g(b,{key:1},[e.value?(o(),c(R,{key:0,"billing-metadata":e.value,"organization-id":s.value},null,8,["billing-metadata","organization-id"])):I("",!0),(o(),c(k,{key:s.value}))],64))]),_:1})]),_:1})}}});export{Y as default};
//# sourceMappingURL=Organization-Dw17jiJL.js.map
