import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-DnP4cDxT.js";import{e as i,n,g as m,p as s}from"./jwt-decode.esm-CZajAnkk.js";import{u as c}from"./projectStore-DZ-D9Wa_.js";import"./router-C8CCuUKN.js";import"./ts.worker-CbdM7mxv.js";import"./fetch-BZqJm27G.js";import"./tables-BosOXgsx.js";import"./string-CFhNxAoY.js";import"./SaveButton-Dk867pAp.js";import"./ExclamationCircleOutlined-BDTMOv1x.js";import"./CrudView-ByZquR2L.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-CLe4i_G7.js";import"./constants-DBenAw06.js";import"./url-CT13c0nd.js";import"./PhDotsThreeVertical.vue-C0z9wHNE.js";import"./index-TXmLIIyx.js";import"./asyncComputed-DXAjR52O.js";import"./PhPencil.vue-B-zdR1aB.js";import"./useCodebaseEvents-BMrCPgGM.js";import"./contracts.generated-BALdEKZ5.js";import"./index-CadB79EP.js";import"./member-D3C_DPKf.js";import"./project-DTFW8XGL.js";import"./organizationSwitcher-C5dAiDRY.js";import"./organization-CkvaBeNd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="c08c058c-86b5-4f5f-bf4c-d633388daf06",o._sentryDebugIdIdentifier="sentry-dbid-c08c058c-86b5-4f5f-bf4c-d633388daf06")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=c(),t=new e(r.projectId);return(f,a)=>(m(),n(p,{"env-var-repository":s(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-CTRwsXh2.js.map
